.. Octomotron documentation master file, created by
   sphinx-quickstart on Wed Jan 25 16:04:02 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Bow Before Octomotron!
======================

`Octomotron` is a tool for continuously deploying many branches of your web 
project for testing, facilitating agile work flows using `git`.  Branches can be 
deployed or removed using a single command, and automatically updated with 
another command.  `Octomotron` detects when your branch has been merged to 
master and automatically removes that branch from deployment.  You provide
`Octomotron` with a descriptor, written in Python, which tells `Octomotron` how
to build and deploy your project, and `Octomotron` takes care of the rest.

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

